@@ -22,7 +22,6 @@ __all__ = [
     'debianize',
     ]
 
-import asyncio
 import contextlib
 from dataclasses import dataclass, field
 import errno
@@ -56,7 +55,7 @@ from breezy.errors import (
     NoSuchRevision,
 )
 from breezy.commit import NullCommitReporter, PointlessCommit
-from breezy.revision import NULL_REVISION
+from breezy.revision import NULL_REVISION, RevisionID
 from breezy.tree import Tree
 from breezy.workingtree import WorkingTree
 
@@ -115,8 +114,10 @@ from breezy.plugins.debian.merge_upstream import (
     get_existing_imported_upstream_revids,
     )
 from breezy.plugins.debian.import_dsc import UpstreamAlreadyImported
-from breezy.plugins.debian.upstream import PackageVersionNotPresent
-from breezy.plugins.debian.upstream.pristinetar import get_pristine_tar_source
+from breezy.plugins.debian.upstream import (
+    PackageVersionNotPresent, UpstreamSource)
+from breezy.plugins.debian.upstream.pristinetar import (
+    get_pristine_tar_source, BasePristineTarSource)
 from breezy.plugins.debian.upstream.branch import (
     upstream_version_add_revision,
     UpstreamBranchSource,
@@ -281,7 +282,8 @@ def setup_debhelper(
     )
 
 
-def default_create_dist(session, tree, package, version, target_dir):
+def default_create_dist(
+        session, tree, package, version, target_dir, subpath=""):
     try:
         with session:
             try:
@@ -289,7 +291,8 @@ def default_create_dist(session, tree, package, version, target_dir):
                     session, tree, target_dir,
                     include_controldir=False,
                     subdir=(package or "package"),
-                    version=version)
+                    version=version,
+                    subpath=subpath)
             except DetailedFailure as e:
                 if isinstance(
                         e.error,
@@ -298,7 +301,7 @@ def default_create_dist(session, tree, package, version, target_dir):
                         session, tree, target_dir,
                         include_controldir=True,
                         subdir=(package or "package"),
-                        version=version)
+                        version=version, subpath=subpath)
                 else:
                     raise
     except NoBuildToolsFound:
@@ -323,7 +326,9 @@ def default_create_dist(session, tree, package, version, target_dir):
 
 def import_upstream_version_from_dist(
         wt, subpath, upstream_source, source_name, upstream_version,
-        session):
+        session: Session) -> Tuple[
+            Dict[Optional[str], Tuple[RevisionID, str]],
+            Dict[Optional[str], RevisionID], str]:
     orig_dir = os.path.abspath(default_orig_dir)
 
     tag_names = {}
@@ -358,8 +363,8 @@ def import_upstream_version_from_dist(
                 upstream_source, source_name, upstream_version)
         pristine_revids = {}
         for (component, tag_name, revid,
-             _pristine_tar_imported) in imported_revids:
-            pristine_revids[component] = revid
+             _pristine_tar_imported, subpath) in imported_revids:
+            pristine_revids[component] = (revid, subpath)
             tag_names[component] = tag_name
 
     upstream_branch_name = "upstream"
@@ -711,7 +716,7 @@ def process_cargo(es, session, wt, subpath, debian_path, upstream_version,
     reset_tree(wt, wt.basis_tree(), subpath)
     from debmutate.debcargo import (
         DebcargoControlShimEditor, unmangle_debcargo_version)
-    crate = metadata.get('X-Cargo-Crate')
+    crate = metadata.get('Cargo-Crate')
     if crate is None:
         crate = metadata['Name'].replace('_', '-')
     if not wt.has_filename(debian_path):
@@ -783,7 +788,7 @@ class DebianizeResult:
     """Debianize result."""
 
     upstream_branch_name: Optional[str] = None
-    tag_names: Dict[Optional[str], str] = field(default_factory=dict)
+    tag_names: Dict[Optional[str], RevisionID] = field(default_factory=dict)
     upstream_version: Optional[str] = None
     wnpp_bugs: List[Tuple[int, str]] = field(default_factory=list)
     vcs_url: Optional[str] = None
@@ -798,8 +803,11 @@ def import_build_deps(source, build_deps):
 
 
 def import_upstream_dist(
-        pristine_tar_source, wt, upstream_source, subpath, source_name,
-        upstream_version, session):
+        pristine_tar_source: BasePristineTarSource, wt: WorkingTree,
+        upstream_source: UpstreamSource, subpath: str, source_name: str,
+        upstream_version: str, session: Session
+        ) -> Tuple[Tuple[RevisionID, str], Optional[str],
+                   Dict[Optional[str], RevisionID]]:
     if pristine_tar_source.has_version(
             source_name, upstream_version, try_hard=False):
         logging.warning(
@@ -808,7 +816,7 @@ def import_upstream_dist(
         pristine_revids = pristine_tar_source\
             .version_as_revisions(source_name, upstream_version)
         upstream_branch_name = None
-        tag_names = {}
+        tag_names: Dict[Optional[str], RevisionID] = {}
     else:
         (pristine_revids, tag_names,
          upstream_branch_name) = import_upstream_version_from_dist(
@@ -817,6 +825,8 @@ def import_upstream_dist(
             source_name, upstream_version,
             session=session)
 
+    assert (isinstance(pristine_revids[None], tuple)
+            and len(pristine_revids[None])), repr(pristine_revids[None])
     return pristine_revids[None], upstream_branch_name, tag_names
 
 
@@ -853,10 +863,10 @@ def get_upstream_version(
     upstream_revision = upstream_source.version_as_revision(
         metadata.get("Name"), mangled_upstream_version)
 
-    if upstream_version is None and "X-Version" in metadata:
+    if upstream_version is None and "Version" in metadata:
         # They haven't done any releases yet. Assume we're ahead of
         # the next announced release?
-        next_upstream_version = debian_upstream_version(metadata["X-Version"])
+        next_upstream_version = debian_upstream_version(metadata["Version"])
         upstream_version = upstream_version_add_revision(
             upstream_source.upstream_branch, next_upstream_version,
             upstream_revision, "~"
@@ -871,12 +881,12 @@ def get_upstream_version(
     return upstream_version, mangled_upstream_version
 
 
-async def find_wnpp_bugs_harder(source_name, upstream_name):
-    wnpp_bugs = await find_wnpp_bugs(source_name)
+def find_wnpp_bugs_harder(source_name, upstream_name):
+    wnpp_bugs = find_wnpp_bugs(source_name)
     if not wnpp_bugs and source_name != upstream_name:
-        wnpp_bugs = await find_wnpp_bugs(upstream_name)
+        wnpp_bugs = find_wnpp_bugs(upstream_name)
     if not wnpp_bugs:
-        wnpp_bugs = await find_archived_wnpp_bugs(source_name)
+        wnpp_bugs = find_archived_wnpp_bugs(source_name)
         if wnpp_bugs:
             logging.warning(
                 "Found archived ITP/RFP bugs for %s: %r",
@@ -1001,9 +1011,10 @@ def debianize(  # noqa: C901
                     "Using upstream version %s", mangled_upstream_version)
 
                 pristine_tar_source = get_pristine_tar_source(wt, wt.branch)
-                (upstream_dist_revid, result.upstream_branch_name,
+                ((upstream_dist_revid, upstream_dist_subpath),
+                 result.upstream_branch_name,
                  result.tag_names) = import_upstream_dist(
-                    pristine_tar_source, wt, upstream_source, upstream_subpath,
+                    pristine_tar_source, wt, upstream_source, subpath,
                     source_name, mangled_upstream_version, session)
 
                 if wt.branch.last_revision() != upstream_dist_revid:
@@ -1013,7 +1024,8 @@ def debianize(  # noqa: C901
 
                     # Gather metadata items again now that we're at the correct
                     # revision
-                    import_metadata_from_path(wt.abspath(subpath))
+                    import_metadata_from_path(
+                        wt.abspath(upstream_dist_subpath))
 
                 if wt.has_filename(debian_path) and force_new_directory:
                     shutil.rmtree(wt.abspath(debian_path))
@@ -1032,7 +1044,8 @@ def debianize(  # noqa: C901
 
             if upstream_source:
                 try:
-                    upstream_vcs_tree = upstream_source.revision_tree(
+                    (upstream_vcs_tree,
+                     upstream_vcs_subpath) = upstream_source.revision_tree(
                         source_name, mangled_upstream_version)
                 except (PackageVersionNotPresent, NoSuchRevision):
                     logging.warning(
@@ -1041,13 +1054,20 @@ def debianize(  # noqa: C901
                         source_name, mangled_upstream_version, upstream_source)
                     exported_upstream_tree_path = None
                 else:
+                    assert upstream_vcs_subpath == ''
                     # TODO(jelmer): Don't export, just access from memory.
                     exported_upstream_tree_path = es.enter_context(
                         TemporaryDirectory())
+                    assert isinstance(upstream_subpath, str)
                     dupe_vcs_tree(
                         upstream_vcs_tree, exported_upstream_tree_path)
-                    import_metadata_from_path(
-                        os.path.join(exported_upstream_tree_path, subpath))
+                    exported_upstream_tree_subpath = os.path.join(
+                        exported_upstream_tree_path, upstream_subpath)
+                    if not os.path.isdir(exported_upstream_tree_subpath):
+                        raise Exception(
+                            f'subdirectory {upstream_subpath} does not '
+                            f'exist in upstream version {upstream_version}')
+                    import_metadata_from_path(exported_upstream_tree_subpath)
 
             if (buildsystem_name is None
                     and exported_upstream_tree_path is not None):
@@ -1097,9 +1117,8 @@ def debianize(  # noqa: C901
                 raise SourcePackageNameInvalid(source['Source'])
 
             if net_access:
-                wnpp_bugs = asyncio.run(
-                    find_wnpp_bugs_harder(
-                        source['Source'], metadata.get('Name')))
+                wnpp_bugs = find_wnpp_bugs_harder(
+                    source['Source'], metadata.get('Name'))
             else:
                 wnpp_bugs = None
 
@@ -1119,10 +1138,11 @@ def debianize(  # noqa: C901
                         control.binaries, version)):
                 logging.warning(
                     'Debianized package (binary packages: %r), version %s '
-                    'did not satisfy requirement %r. '
-                    'Wrong repository (%s)?',
+                    'did not satisfy requirement %r. ',
                     [binary['Package'] for binary in control.binaries],
-                    version, requirement, upstream_branch)
+                    version, requirement)
+                if upstream_branch:
+                    logging.info('Wrong repository (%s)?', upstream_branch)
                 raise DebianizedPackageRequirementMismatch(
                     requirement, control, version,
                     upstream_branch)
@@ -1552,6 +1572,9 @@ def main(argv=None):  # noqa: C901
         loglevel = logging.INFO
     logging.basicConfig(level=loglevel, format='%(message)s')
 
+    # pysimplesoap is quite verbose
+    logging.getLogger('pysimplesoap.client').setLevel(logging.ERROR)
+
     logging.warning(
         'debianize is experimental and often generates packaging '
         'that is incomplete or does not build as-is. '
@@ -1574,9 +1597,10 @@ def main(argv=None):  # noqa: C901
 
     create_dist: Optional[Callable[[Tree, str, str, str], str]]
     if args.dist_command:
-        def create_dist(tree, package, version, target_dir):
+        def create_dist(tree, package, version, target_dir, subpath=""):
             return run_dist_command(
-                tree, package, version, target_dir, args.dist_command)
+                tree, package, version, target_dir, args.dist_command,
+                subpath=subpath)
     else:
         create_dist = None
 
@@ -1817,13 +1841,16 @@ def main(argv=None):  # noqa: C901
                 logging.fatal('Error during %s: %s', phase, e.description)
                 return 1
             except DebianizedPackageRequirementMismatch as e:
+                if upstream_branch:
+                    hint = 'Wrong repository (%s)?' % e.upstream_branch
+                else:
+                    hint = None
                 report_fatal(
                     'package-requirements-mismatch',
                     'Debianized package (binary packages: %r), version %s '
-                    'did not satisfy requirement %r. '
-                    'Wrong repository (%s)?' % (
+                    'did not satisfy requirement %r. ' % (
                         [binary['Package'] for binary in e.control.binaries],
-                        e.version, e.requirement, e.upstream_branch))
+                        e.version, e.requirement), hint=hint)
                 return 1
             logging.info('Built %r.', changes_names)
             if args.install:
