@@ -17,24 +17,22 @@
 
 """Support for accessing UDD."""
 
-import asyncio
+import os
+
+
+DEFAULT_UDD_URL = (
+    'postgresql://udd-mirror:udd-mirror@udd-mirror.debian.net:5432/udd')
 
 
 _pool = None
 
 
-async def connect_udd_mirror():
-    import asyncpg
+def connect_udd_mirror():
+    import psycopg2
 
     global _pool
     if not _pool:
-        loop = asyncio.get_event_loop()
-        _pool = await asyncpg.create_pool(
-            database="udd",
-            user="udd-mirror",
-            password="udd-mirror",
-            port=5432,
-            host="udd-mirror.debian.net",
-            loop=loop,
-        )
-    return _pool.acquire()
+        udd_url = os.environ.get('UDD_URL', DEFAULT_UDD_URL)
+        _pool = psycopg2.connect(udd_url)
+        _pool.set_client_encoding('UTF8')
+    return _pool
